@@ -22,7 +22,6 @@ except:
     pass
 from time import sleep as __sleep
 
-
 # try:
 #     from pip import main as pipmain
 # except ImportError:
@@ -62,9 +61,6 @@ __workers__ = []
 __telegrambot_name__ = 'ht-bot'
 __telegrambot_token__ = ''
 
-global __is_all_loaded__
-__is_all_loaded__ = False
-
 def __checkLibraryUpdate__():
     try:
         # Check Version Update
@@ -127,14 +123,10 @@ def getModule(moduleName):
     #Logger.printMessage('Initiation of {moduleName}'.format(moduleName=moduleName), debug_module=True)
 
     # While the mods are loading with workers, wait por it
+    print(getWorkers())
     while any( [ work.startswith('import-module-') for work in getWorkers() ] ):
         __sleep(0.1)
 
-    global __is_all_loaded__
-    while not __is_all_loaded__:
-        print('loading modules yet, please wait')
-        __sleep(0.3)
-
     for m in __modules_loaded__:
         if moduleName in m:
             if not 'ht_' in moduleName:
@@ -230,6 +222,7 @@ def wantPool():
     return __WANT_TO_BE_IN_POOL__
 
 def worker(workerName, functionCall, args=(), timesleep=1, loop=True, run_until_ht_stops=False, log=False, timeout=None):
+    print(workerName)
     Utils.startWorker(workerName, functionCall, args, int(timesleep), loop, run_until_ht_stops, log, timeout)
     if loop:
         __workers__.append(workerName)
@@ -589,6 +582,7 @@ def __importModules__():
             for files in modules[modu][submod]:
                 try:
                     module_name = modules[modu][submod][files][0].split(".")[0]
+                    print('__amidjango__', __amidjango__)
                     if not __amidjango__:
                         worker("import-module-{m}".format(m=module_name), 'ht.__importModule__', args=(modu, submod, module_name), loop=False, log=False) # Threaded
                     else:
@@ -596,8 +590,6 @@ def __importModules__():
                 except Exception as e:
                     Logger.printMessage(message='__importModules__', description='{moduleName} File not found: {error}'.format(moduleName=files, error=str(e)), is_error=True)
                     pass
-    global __is_all_loaded__
-    __is_all_loaded__ = True
 
 worker('check-library-updated', 'ht.__checkLibraryUpdate__', loop=False, run_until_ht_stops=True, log=__amidjango__)
 worker('refresh-pool-servers', 'ht.Pool.__checkPoolNodes__', timesleep=180, run_until_ht_stops=True, log=__amidjango__)
